##  Prepare Initiatives for Your Roadmap
The following steps are needed to create your roadmap:
  1. Go to Inventory.
  2. Optional: Create an Objective fact sheets that shows alignment with your business and IT strategy. You can also reuse existing objectives.
  3. Create a new Initiative fact sheet, e.g., 'Application Rationalization Initiative'.
![Create fact sheet dialog with initiative type and subtype options like Idea, program, project, and epic](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loioabe78bfc20e94a0e9007a2c804e6dea0_HiRes.png)
  4. Optional: Create additional child Initiative Fact Sheets for each TIME classification and link them via the Parent relation to the application rationalization initiative. If necessary, create a third hierarchy level of child Initiatives for each sub-project within each of the TIME classifications.
  5. Optional: Link the initiative fact sheets to your previously defined Objective fact sheet(s) to outline how they are supporting your strategy.
  6. Add Applications to the respective initiative fact sheets by filtering for the attribute TIME classification.
![Application selection list in an initiative fact sheet](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio12e60ca52d2148edb52a6185f8067e08_HiRes.png)
